# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...non_insurance_payers.resources.v_1.types.non_insurance_payer_id import NonInsurancePayerId
from .patient_clinical_trial_info_create import PatientClinicalTrialInfoCreate


class PatientNonInsurancePayerInfoCreate(UniversalBaseModel):
    non_insurance_payer_id: NonInsurancePayerId
    member_id: typing.Optional[str] = None
    clinical_trial_info: typing.Optional[typing.List[PatientClinicalTrialInfoCreate]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
