# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OccurrenceInformationCodeQualifier(str, enum.Enum):
    CBH = "BH"
    """
    Occurrence
    """

    _UNKNOWN = "__OCCURRENCEINFORMATIONCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OccurrenceInformationCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(self, cbh: typing.Callable[[], T_Result], _unknown_member: typing.Callable[[str], T_Result]) -> T_Result:
        if self is OccurrenceInformationCodeQualifier.CBH:
            return cbh()
        return _unknown_member(self._value_)
