# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.street_address_short_zip import StreetAddressShortZip


class GuarantorBase(UniversalBaseModel):
    first_name: str
    last_name: str
    external_id: str
    date_of_birth: typing.Optional[dt.date] = None
    address: StreetAddressShortZip

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
